@@ -86,8 +86,10 @@ bool Mixer::pulseaudioPresent()
 }
 
 
-Mixer::Mixer( QString& ref_driverName, int device )
-    : m_balance(0), _mixerBackend(0L), m_dynamic(false)
+Mixer::Mixer(const QString &ref_driverName, int device)
+    : m_balance(0),
+      _mixerBackend(nullptr),
+      m_dynamic(false)
 {
     _mixerBackend = 0;
     int driverCount = numDrivers();
@@ -243,48 +245,41 @@ void Mixer::volumeLoad( KConfig *config )
  * Opens the mixer.
  * Also, starts the polling timer, for polling the Volumes from the Mixer.
  *
- * @param cardId The cardId Usually this will be 1, but if there is
- * more than one card with the same name install, then you need
- * to use 2, 3, ...
- *
  * @return true, if Mixer could be opened.
  */
 bool Mixer::openIfValid()
 {
-	if (_mixerBackend == 0 )
-	{
-		// if we did not instantiate a suitable Backend, then Mixer is invalid
-		return false;
-	}
-
-    bool ok = _mixerBackend->openIfValid();
-    if ( ok )
+    if (_mixerBackend==nullptr)
     {
-        recreateId();
-        shared_ptr<MixDevice> recommendedMaster = _mixerBackend->recommendedMaster();
-        if ( recommendedMaster.get() != 0 )
-        {
-            QString recommendedMasterStr = recommendedMaster->id();
-            setLocalMasterMD( recommendedMasterStr );
-            qCDebug(KMIX_LOG) << "Mixer::open() detected master: " << recommendedMaster->id();
-        }
-        else
-        {
-            if ( !m_dynamic )
-                qCCritical(KMIX_LOG) << "Mixer::open() no master detected.";
-            else
-                qCDebug(KMIX_LOG) << "Mixer::open() no master detected.";
-            QString noMaster = "---no-master-detected---";
-            setLocalMasterMD(noMaster); // no master
-        }
-        // cesken: The following connect() looks mighty strange. I removed it on 2013-12-18
-        //connect( _mixerBackend, SIGNAL(controlChanged()), SIGNAL(controlChanged()) );
-        new DBusMixerWrapper(this, dbusPath());
+        // If we did not instantiate a suitable backend, then the mixer is invalid.
+        qCWarning(KMIX_LOG) << "no mixer backend";
+        return false;
     }
 
-    return ok;
+    bool ok = _mixerBackend->openIfValid();
+    if (!ok) return (false);
+
+    recreateId();
+    shared_ptr<MixDevice> recommendedMaster = _mixerBackend->recommendedMaster();
+    if (recommendedMaster.get()!=nullptr)
+    {
+        QString recommendedMasterStr = recommendedMaster->id();
+        setLocalMasterMD( recommendedMasterStr );
+        qCDebug(KMIX_LOG) << "Detected master" << recommendedMaster->id();
+    }
+    else
+    {
+        if (!m_dynamic) qCCritical(KMIX_LOG) << "No master detected and not dynamic";
+        else qCDebug(KMIX_LOG) << "No master detected but dynamic";
+        QString noMaster = "---no-master-detected---";
+        setLocalMasterMD(noMaster); // no master
+    }
+
+    new DBusMixerWrapper(this, dbusPath());
+    return (true);
 }
 
+
 /**
  * Closes the mixer.
  */
@@ -316,7 +311,7 @@ MixSet& Mixer::getMixSet()
 /**
  * Returns the driver name, that handles this Mixer.
  */
-QString Mixer::getDriverName()
+QString Mixer::getDriverName() const
 {
   QString driverName = _mixerBackend->getDriverName();
 //  qCDebug(KMIX_LOG) << "Mixer::getDriverName() = " << driverName << "\n";
@@ -393,19 +388,8 @@ void Mixer::setBalanceInternal(Volume& vol)
 /**
  * Returns a name suitable for a human user to read (on a label, ...)
  */
-QString Mixer::readableName()
-{
-	return readableName(false);
-}
 
-/**
- * Returns a name suitable for a human user to read, possibly with quoted ampersand. The latter is required by
- * some GUI elements like QRadioButton or when used as a Tab label, as '&' introduces an accelerator there.
- *
- * @param ampersandQuoted
- * @return
- */
-QString Mixer::readableName(bool ampersandQuoted)
+QString Mixer::readableName(bool ampersandQuoted) const
 {
 	QString finalName = _mixerBackend->getName();
 	if (ampersandQuoted)
@@ -419,7 +403,7 @@ QString Mixer::readableName(bool ampersandQuoted)
 }
 
 
-QString Mixer::getBaseName()
+QString Mixer::getBaseName() const
 {
   return _mixerBackend->getName();
 }
@@ -444,12 +428,13 @@ void Mixer::setID(QString& ref_id)
 }
 */
 
-QString& Mixer::id()
+const QString &Mixer::id() const
 {
   return _id;
 }
 
-QString& Mixer::udi(){
+const QString &Mixer::udi() const
+{
     return _mixerBackend->udi();
 }
 
@@ -578,7 +563,7 @@ QString Mixer::getRecommendedDeviceId()
     return QString();
 }
 
-shared_ptr<MixDevice> Mixer::getLocalMasterMD()
+shared_ptr<MixDevice> Mixer::getLocalMasterMD() const
 {
     if (_mixerBackend && _masterDevicePK.isEmpty())
         return _mixerBackend->recommendedMaster();
@@ -591,7 +576,7 @@ void Mixer::setLocalMasterMD(QString &devPK)
 }
 
 
-shared_ptr<MixDevice> Mixer::find(const QString& mixdeviceID)
+shared_ptr<MixDevice> Mixer::find(const QString& mixdeviceID) const
 {
 
 	shared_ptr<MixDevice> mdRet;
@@ -659,7 +644,7 @@ void Mixer::commitVolumeChange(shared_ptr<MixDevice> md)
 		<< "committing announces the change of: " << md->id();
 
 	// We announce the change we did, so all other parts of KMix can pick up the change
-	ControlManager::instance().announce(md->mixer()->id(), ControlChangeType::Volume,
+	ControlManager::instance().announce(md->mixer()->id(), ControlManager::Volume,
 		QString("Mixer.commitVolumeChange()"));
 }
 
@@ -703,7 +688,7 @@ void Mixer::increaseOrDecreaseVolume( const QString& mixdeviceID, bool decrease
 
         _mixerBackend->writeVolumeToHW(mixdeviceID, md);
     }
-   ControlManager::instance().announce(md->mixer()->id(), ControlChangeType::Volume, QString("Mixer.increaseOrDecreaseVolume()"));
+   ControlManager::instance().announce(md->mixer()->id(), ControlManager::Volume, QString("Mixer.increaseOrDecreaseVolume()"));
 
     /************************************************************
         It is important, not to implement this method like this:
@@ -729,7 +714,7 @@ bool Mixer::moveStream( const QString id, const QString& destId )
 {
     // We should really check that id is within our md's....
     bool ret = _mixerBackend->moveStream( id, destId );
-    ControlManager::instance().announce(QString(), ControlChangeType::ControlList, QString("Mixer.moveStream()"));
+    ControlManager::instance().announce(QString(), ControlManager::ControlList, QString("Mixer.moveStream()"));
     return ret;
 }
 
